yakumo.glance.v1.image.Resource

Package yakumo :: Package glance :: Package v1 :: Module image :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for images on Image V1 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, uri=`'``__UNDEF__``'`, disk_format=`'``__UNDEF__``'`, container_format=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, virtual_size=`'``__UNDEF__``'`, checksum=`'``__UNDEF__``'`, min_ram=`'``__UNDEF__``'`, min_disk=`'``__UNDEF__``'`, owner=`'``__UNDEF__``'`, properties=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`, file=None) Update properties of an image | source code
None |
download(self, file=None) Download an image into a local file | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _stable_state = ``[``'``active``'``,` `'``killed``'``,` `'``deleted``'``,` `'``deactivated``'``]``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, uri=`'``__UNDEF__``'`, disk_format=`'``__UNDEF__``'`, container_format=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, virtual_size=`'``__UNDEF__``'`, checksum=`'``__UNDEF__``'`, min_ram=`'``__UNDEF__``'`, min_disk=`'``__UNDEF__``'`, owner=`'``__UNDEF__``'`, properties=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`, file=None) | source code
Update properties of an image Parameters: `name` (str) - Image name `uri` (str) - URI to the Image `disk_format` (str) - Disk format `container_format` (str) - Container format `size` (int) - Actual file size `virtual_size` (int) - Virtual disk size `checksum` (str) - Checksum `min_ram` (int) - Minimum RAM size of the VM with the image `owner` (str) - Owner of the image `properties` (dict) - Properties `is_public` (bool) - Whether this is public or not `file` (str) - File to upload Returns: None Overrides: base.Resource.update

### download(self, file=None) | source code
Download an image into a local file Parameters: `file` (str) - File name to save (required) Returns: None